// Set up the SVG width, height, and margins
const width = 800;
const height = 400;
const margin = { top: 50, right: 50, bottom: 50, left: 50 };

// Select the div container for the line chart
const svg = d3
  .select('#line-chart')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Load the CSV data using D3
d3.csv(
  'https://gist.githubusercontent.com/sriramofficial9/e62b48a21988996d62fb6854f135b66e/raw/e78541fe031100c1f75273cbcf4e13bd043f0fca/titanic.csv',
).then(function (data) {
  // Extract years from the headers
  const years = data.columns.slice(1);

  // Initialize an empty array to store total sales for each year
  const totalSales = [];

  // Calculate total sales for each year
  years.forEach((year) => {
    let sum = 0;
    data.forEach((d) => {
      sum += +d[year];
    });
    totalSales.push({
      year: d3.timeParse('%Y')(year),
      sales: sum,
    });
  });

  // Create scales for x-axis and y-axis
  const xScale = d3
    .scaleTime()
    .domain(d3.extent(totalSales, (d) => d.year))
    .range([margin.left, width - margin.right]);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(totalSales, (d) => d.sales)])
    .range([height - margin.bottom, margin.top]);

  // Create line generator
  const lineGenerator = d3
    .line()
    .x((d) => xScale(d.year))
    .y((d) => yScale(d.sales));

  // Draw the line
  svg
    .append('path')
    .datum(totalSales)
    .attr('fill', 'none')
    .attr('stroke', 'steelblue')
    .attr('stroke-width', 2)
    .attr('d', lineGenerator);

  // Add x-axis
  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - margin.bottom})`,
    )
    .call(d3.axisBottom(xScale));

  // Add y-axis
  svg
    .append('g')
    .attr('transform', `translate(${margin.left},0)`)
    .call(d3.axisLeft(yScale));

  // Add x-axis label
  svg
    .append('text')
    .attr('class', 'x-label')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', height - 10)
    .text('Year');

  // Add y-axis label
  svg
    .append('text')
    .attr('class', 'y-label')
    .attr('text-anchor', 'middle')
    .attr('x', -height / 2)
    .attr('y', 10)
    .attr('dy', '.75em')
    .attr('transform', 'rotate(-90)')
    .text('Total Sales');
});
